

# -*- coding:utf-8 -*-
from distutils.core import setup
from setuptools import find_packages

setup(name='smrtnet',
        version='0.1',
        packages=find_packages(),
        include_package_data=True,
        package_data={'data': ['data/SMRTnet-data-demo.txt'],\
                      'Figures': ['img_log/*.*'],\
                      'vocab':['LM_Mol/bert_vocab.txt']},
        python_requires="==3.8.10",
        description='A python lib for predicting small molecule-RNA interactions (SRIs)',
        long_description='Small molecules can bind RNAs to regulate their fate and functions, providing promising opportunities for treating human diseases. However, current tools for predicting small molecule-RNA interactions (SRIs) require prior knowledge of RNA tertiary structures, limiting their utility in drug discovery. Here, we present SMRTnet, a deep learning method to predict SRIs based on RNA secondary structure. By integrating large language models, convolutional neural networks, graph attention networks, and multimodal data fusion, SMRTnet achieves high performance across multiple experimental benchmarks, substantially outperforming existing state-of-the-art tools.',
        author='yuhan_Fei & jiasheng_Zhang',
        author_email='yuhan_fei@outlook.com',
        url='https://github.com/Yuhan-Fei/SMRTnet',  # homepage
        license='MIT',
        install_requires=["absl-py==2.1.0",
"aiohappyeyeballs==2.4.4",
"aiohttp==3.10.11",
"aiosignal==1.3.1",
"anyio==4.5.2",
"argon2-cffi==23.1.0",
"argon2-cffi-bindings==21.2.0",
"arrow==1.3.0",
"asttokens==3.0.0",
"async-lru==2.0.4",
"async-timeout==5.0.1",
"attrs==25.1.0",
"babel==2.17.0",
"backcall==0.2.0",
"beautifulsoup4==4.13.3",
"bleach==6.1.0",
"Brotli==1.1.0",
"cachetools==5.5.2",
"certifi==2024.2.2",
"cffi==1.17.1",
"charset-normalizer==3.3.2",
"cloudpickle==3.0.0",
"colorama==0.4.6",
"comm==0.2.2",
"conda-pack==0.8.1",
"contourpy==1.1.1",
"cycler==0.12.1",
"debugpy==1.8.12",
"decorator==5.2.1",
"defusedxml==0.7.1",
"dgllife==0.3.2",
"exceptiongroup==1.2.2",
"executing==2.2.0",
"fastjsonschema==2.21.1",
"filelock==3.13.1",
"fonttools==4.56.0",
"fqdn==1.5.1",
"frozenlist==1.5.0",
"fsspec==2024.6.1",
"future==1.0.0",
"google-auth==2.38.0",
"google-auth-oauthlib==1.0.0",
"grpcio==1.70.0",
"h11==0.14.0",
"httpcore==1.0.7",
"httpx==0.28.1",
"huggingface-hub==0.29.1",
"hyperopt==0.2.7",
"idna==3.10",
"importlib_metadata==8.5.0",
"importlib_resources==6.4.5",
"ipykernel==6.29.5",
"ipython==8.12.3",
"ipywidgets==8.1.5",
"isoduration==20.11.0",
"jedi==0.19.2",
"Jinja2==3.1.4",
"joblib==1.4.2",
"json5==0.10.0",
"jsonpointer==3.0.0",
"jsonschema==4.23.0",
"jsonschema-specifications==2023.12.1",
"jupyter_client==8.6.3",
"jupyter_core==5.7.2",
"jupyter-events==0.10.0",
"jupyter-lsp==2.2.5",
"jupyter_server==2.14.2",
"jupyter_server_terminals==0.5.3",
"jupyterlab==4.3.5",
"jupyterlab_pygments==0.3.0",
"jupyterlab_server==2.27.3",
"jupyterlab_widgets==3.0.13",
"kiwisolver==1.4.7",
"Markdown==3.7",
"MarkupSafe==2.1.5",
"matplotlib==3.7.5",
"matplotlib-inline==0.1.7",
"mistune==3.1.2",
"mpmath==1.3.0",
"multidict==6.1.0",
"nbclient==0.10.1",
"nbconvert==7.16.6",
"nbformat==5.10.4",
"nest-asyncio==1.6.0",
"networkx==2.8.8",
"notebook==7.3.2",
"notebook_shim==0.2.4",
"numpy==1.20.3",
"oauthlib==3.2.2",
"overrides==7.7.0",
"packaging==24.2",
"pandas==1.2.4",
"pandocfilters==1.5.1",
"parso==0.8.4",
"pexpect==4.9.0",
"pickleshare==0.7.5",
"pillow==10.2.0",
"pip==24.3.1",
"pkgutil_resolve_name==1.3.10",
"platformdirs==4.3.6",
"pooch==1.8.2",
"prefetch_generator==1.0.3",
"prettytable==3.11.0",
"prometheus_client==0.21.1",
"prompt_toolkit==3.0.50",
"propcache==0.2.0",
"protobuf==5.29.3",
"psutil==5.9.8",
"ptyprocess==0.7.0",
"pure_eval==0.2.3",
"py4j==0.10.9.7",
"pyasn1==0.6.1",
"pyasn1_modules==0.4.1",
"pychimera==0.2.7",
"pycparser==2.22",
"Pygments==2.19.1",
"pyparsing==3.1.4",
"PySocks==1.7.1",
"python-dateutil==2.8.2",
"python-json-logger==3.2.1",
"pytorch-lightning==1.1.5",
"pytz==2024.2",
"PyYAML==6.0.2",
"pyzmq==26.2.1",
"rdkit==2022.3.5",
"referencing==0.35.1",
"regex==2024.11.6",
"requests==2.32.3",
"requests-oauthlib==2.0.0",
"rfc3339-validator==0.1.4",
"rfc3986-validator==0.1.1",
"rpds-py==0.20.1",
"rsa==4.9",
"scikit-learn==0.24.2",
"scipy==1.10.1",
"seaborn==0.13.2",
"Send2Trash==1.8.3",
"setuptools==75.3.0",
"six==1.16.0",
"sniffio==1.3.1",
"soupsieve==2.6",
"stack-data==0.6.3",
"sympy==1.13.1",
"tensorboard==2.14.0",
"tensorboard-data-server==0.7.2",
"tensorboardX==2.6.2.2",
"terminado==0.18.1",
"threadpoolctl==3.5.0",
"tinycss2==1.2.1",
"tokenizers==0.13.3",
"tomli==2.2.1",
"tornado==6.4.2",
"tqdm==4.67.1",
"traitlets==5.14.3",
"transformers==4.28.1",
"triton==3.0.0",
"types-python-dateutil==2.9.0.20241206",
"typing_extensions==4.12.2",
"uri-template==1.3.0",
"urllib3==2.2.1",
"wcwidth==0.2.13",
"webcolors==24.8.0",
"webencodings==0.5.1",
"websocket-client==1.8.0",
"Werkzeug==3.0.6",
"wheel==0.45.1",
"widgetsnbextension==4.0.13",
"xsmiles==0.2.2",
"yarl==1.15.2",
"zipp==3.20.2",
]
    )









